@@ -194,7 +194,7 @@ passenger_create_loc_conf(ngx_conf_t *cf)
     DEFINE_VAR_TO_PASS("SCGI",            "1");
     DEFINE_VAR_TO_PASS("QUERY_STRING",    "$query_string");
     DEFINE_VAR_TO_PASS("REQUEST_METHOD",  "$request_method");
-    DEFINE_VAR_TO_PASS("REQUEST_URI",     "$request_uri");
+    DEFINE_VAR_TO_PASS("REQUEST_URI",     "$uri$is_args$args");
     DEFINE_VAR_TO_PASS("SERVER_PROTOCOL", "$server_protocol");
     DEFINE_VAR_TO_PASS("SERVER_SOFTWARE", "nginx/$nginx_version");
     DEFINE_VAR_TO_PASS("REMOTE_ADDR",     "$remote_addr");
