@@ -1,5 +1,5 @@
 #!/usr/bin/env ruby
-$LOAD_PATH << "#{File.dirname(__FILE__)}/../../lib"
+$LOAD_PATH.unshift("#{File.dirname(__FILE__)}/../../lib")
 require 'phusion_passenger/message_channel'
 
 include PhusionPassenger
